@@ -29,18 +29,9 @@ sub new {
 		"--no-daemon",
 		"--refresh-dependencies",
 		"--gradle-user-home", ".gradle",
-		"-Duser.home=.",
-		"-Duser.name=debian",
 	#	"--init-script", "/usr/share/gradle-debian-helper/init.gradle",
 		);	
 
-	my $numthreads = $this->get_parallel();
-	if ($numthreads == -1) {
-		push(@{$this->{gradle_cmd}}, "--parallel");
-	} elsif ($numthreads > 1) {
-		push(@{$this->{gradle_cmd}}, "--parallel", "--max-workers=$numthreads");
-	}
-
 	return $this;
 }
 
@@ -62,8 +53,7 @@ sub clean {
 	my $this=shift;
 
 	$this->doit_in_builddir("find . -wholename .*build/tmp | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
-	$this->doit_in_builddir("find . -wholename .*build/debian | xargs echo | sed -e 's^build/tmp^build^g' | xargs rm -Rf");
-	$this->doit_in_builddir("rm", "-Rf", "$this->{cwd}/.gradle", "$this->{cwd}/buildSrc/.gradle", ".m2");
+	$this->doit_in_builddir("rm", "-Rf", "$this->{cwd}/.gradle", "$this->{cwd}/buildSrc/.gradle");
 }
 
 1
